@@ -31,8 +31,8 @@ BEGIN { *esc = \&Pod::Simple::HTML::esc }
 # Note that if you leave out a category here, it will not be indexed
 # in the contents file, even though its HTML POD will still exist.
 use constant FILE_TRANSLATION => {
-    Files      => ['importxml', 'contrib', 'checksetup', 'email_in', 'install-module',
-                   'sanitycheck'],
+    Files      => ['importxml', 'contrib', 'checksetup', 'email_in', 
+                   'install-module', 'sanitycheck', 'jobqueue', 'migrate'],
     Modules    => ['bugzilla'],
     Extensions => ['extensions'],
 };
@@ -106,4 +106,14 @@ sub note_for_contents_file {
     return $retval;
 }
 
+# Exclude modules being in lib/.
+sub find_all_pods {
+    my($self, $dirs) = @_;
+    my $mod2path = $self->SUPER::find_all_pods($dirs);
+    foreach my $mod (keys %$mod2path) {
+        delete $mod2path->{$mod} if $mod =~ /^lib::/;
+    }
+    return $mod2path;
+}
+
 1;
